# =====================================
# generator=datazen
# version=2.1.0
# hash=1650ed0ffb4f69b694c413014dfb5db3
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A collection of core Python utilities."
PKG_NAME = "vcorelib"
VERSION = "0.10.1"

DEFAULT_INDENT = 2
DEFAULT_ENCODING = "utf-8"



"""
Utilities for logging information.
"""

# built-in
from contextlib import contextmanager
from logging import INFO as _INFO
from logging import Logger
from typing import Iterator as _Iterator

# internal
from vcorelib.math.time import TIMER as _TIMER


@contextmanager
def log_time(
    log: Logger,
    message: str,
    *args,
    level: int = _INFO,
    **kwargs,
) -> _Iterator[None]:
    """
    A simple context manager for conveniently logging time taken for a task.
    """
    with _TIMER.log(log, message, *args, level=level, **kwargs):
        yield



"""
A module for context managers related to file-system paths.
"""

# built-in
from contextlib import contextmanager
from os import chdir as _chdir
from pathlib import Path as _Path
from typing import Iterator as _Iterator

# internal
from vcorelib.paths import Pathlike as _Pathlike
from vcorelib.paths import normalize as _normalize


@contextmanager
def in_dir(path: _Pathlike) -> _Iterator[None]:
    """Change the current working directory as a context manager."""

    cwd = _Path.cwd()
    try:
        _chdir(_normalize(path))
        yield
    finally:
        _chdir(cwd)
